'use strict';

const expect = require('chai').expect;

const urlUtility = require('../../../lib/utils/url-utils');


describe('Utils test - url utility', () => {
    describe('# test function isValidUrl', () => {
        [
            {
                testCase: 'input url string is null',
                urlString: null,
                expectation: false
            },
            {
                testCase: 'input url string is undefined',
                urlString: undefined,
                expectation: false
            },
            {
                testCase: 'input url string is empty',
                urlString: '',
                expectation: false
            },
            {
                testCase: 'input url string is blank',
                urlString: '        ',
                expectation: false
            },
            {
                testCase: 'input url string is random string',
                urlString: 'aaaaaaaaaaaaabbbbbbbbbbbsssssssssssssss',
                expectation: false
            },
            {
                testCase: 'input url string does not have protocol',
                urlString: 'www.abc.com',
                expectation: false
            },
            {
                testCase: 'input url string is http',
                urlString: 'http://test.tail',
                expectation: true
            },
            {
                testCase: 'input url string is https',
                urlString: 'https://test.safe',
                expectation: true
            }
        ].forEach(({ testCase, urlString, expectation }) => {
            it(`| ${testCase}, expect isValidResult ${expectation}`, () => {
                // call
                const callResult = urlUtility.isValidUrl(urlString);
                // verify
                expect(callResult).equal(expectation);
            });
        });
    });
});



